@@ -20,19 +20,19 @@
 # https://www.biochem.mpg.de/doc_tom/TOM_Release_2008/IOfun/tom_mrcread.html
 # and https://ami.scripps.edu/software/mrctools/mrc_specification.php
 
-import os
 import logging
+import os
+
 import numpy as np
 
 from rsciio._docstrings import (
+    ENDIANESS_DOC,
     FILENAME_DOC,
     LAZY_DOC,
-    ENDIANESS_DOC,
     RETURNS_DOC,
 )
-from rsciio.utils.tools import sarray2dict
 from rsciio.utils.elements import atomic_number2name
-
+from rsciio.utils.tools import sarray2dict
 
 _logger = logging.getLogger(__name__)
 
@@ -591,7 +591,7 @@ def get_ipr_dtype_list(endianess="<", version=333):
     dtype_list = [
         ("version", end + "u2"),
         ("imageType", end + "u2"),
-        ("label", end + "a8"),
+        ("label", end + "S8"),
         ("sMin", end + "u2"),
         ("sMax", end + "u2"),
         ("color", end + "u2"),
@@ -618,7 +618,7 @@ def get_ipr_dtype_list(endianess="<", version=333):
         ("mppX", end + "f4"),
         ("mppY", end + "f4"),
         ("nTextLines", end + "u2"),
-        ("charText", end + "4a32"),
+        ("charText", end + "4S32"),
         ("reserved3", end + "4f4"),
         ("nOverlayElements", end + "u2"),
         ("overlayColors", end + "16u2"),
