@@ -17,17 +17,18 @@
 # along with HyperSpy. If not, see <https://www.gnu.org/licenses/#GPL>.
 
 import gc
-import pytest
-from pathlib import Path
-from copy import deepcopy
+import importlib
 import shutil
+from copy import deepcopy
+from pathlib import Path
 
 import numpy as np
-
-hs = pytest.importorskip("hyperspy.api", reason="hyperspy not installed")
+import pytest
 
 from rsciio.tests.generate_renishaw_test_file import WDFFileGenerator, WDFFileHandler
 
+hs = pytest.importorskip("hyperspy.api", reason="hyperspy not installed")
+
 testfile_dir = Path(__file__).parent / "data" / "renishaw"
 
 testfile_spec = (testfile_dir / "renishaw_test_spectrum.wdf").resolve()
@@ -812,7 +813,10 @@ class TestSpec:
         assert expected_WARP1 == self.s.original_metadata.WARP_1.as_dictionary()
 
     def test_original_metadata_TEXT(self):
-        expected_TEXT = "A single scan measurement generated by the WiRE spectral acquisition wizard."
+        expected_TEXT = (
+            "A single scan measurement generated by the "
+            "WiRE spectral acquisition wizard."
+        )
         assert expected_TEXT == self.s.original_metadata.TEXT_0
 
     def test_original_metadata_ORGN(self):
@@ -845,12 +849,10 @@ class TestSpec:
         assert metadata["General"]["title"] == "Single scan measurement 7"
 
         assert metadata["Signal"]["quantity"] == "Intensity (Counts)"
-        try:
-            import lumispy
-
-            signal_type = "Luminescence"
-        except ImportError:
+        if importlib.util.find_spec("lumispy") is None:
             signal_type = ""
+        else:
+            signal_type = "Luminescence"
         assert metadata["Signal"]["signal_type"] == signal_type
 
         assert metadata["Acquisition_instrument"]["Detector"]["detector_type"] == "CCD"
@@ -1217,7 +1219,7 @@ class TestStreamline:
         }
 
         for i, (axis, scale) in enumerate(
-            zip(s.axes_manager._axes, (22.570833, 23.710106))
+            zip(s.axes_manager._axes, (1.1285417, 1.1855053))
         ):
             assert axis.units == "µm"
             np.testing.assert_allclose(axis.scale, scale)
