@@ -16,17 +16,16 @@
 # You should have received a copy of the GNU General Public License
 # along with RosettaSciIO. If not, see <https://www.gnu.org/licenses/#GPL>.
 
+import sys
 from pathlib import Path
 
 import numpy as np
 import pytest
 
+from rsciio.tia._api import file_reader, load_ser_file
+
 hs = pytest.importorskip("hyperspy.api", reason="hyperspy not installed")
-
-import traits.api as t
-
-from rsciio.tia._api import load_ser_file, file_reader
-
+t = pytest.importorskip("traits.api", reason="traits not installed")
 
 TEST_DATA_PATH = Path(__file__).parent / "data" / "tia"
 TEST_DATA_PATH_NEW = TEST_DATA_PATH / "new"
@@ -37,9 +36,11 @@ TEST_DATA_PATH_OLD = TEST_DATA_PATH / "old"
 def prepare_non_zero_float():
     import tarfile
 
+    kwargs = {"filter": "data"} if sys.version_info.minor >= 12 else {}
+
     tgz_fname = TEST_DATA_PATH_OLD / "non_float_meta_value_zeroed.tar.gz"
     with tarfile.open(tgz_fname, "r:gz") as tar:
-        tar.extractall(path=TEST_DATA_PATH_OLD)
+        tar.extractall(path=TEST_DATA_PATH_OLD, **kwargs)
 
     yield
 
